@@ -2,8 +2,11 @@ import csv
 from datetime import datetime
 import dateutil.tz
 import feedparser
+from .manual_activity import ManualActivity
 import os
 from .post import Post
+import urllib.request
+import yaml
 
 
 class Home():
@@ -61,54 +64,52 @@ class Home():
         self.posts = []
         self.activities = []
 
-        self.feed = feedparser.parse(
-            'http://www.facebook.com/feeds/'
-            'page.php?format=atom10&id=121855461256134'
+        sohr = urllib.request.urlopen(
+            'http://173.230.141.9/sohr.yaml'
         )
 
+        self.sohr = yaml.load(sohr)
+
         self.entered_date = input(
-            '\nPlease enter a starting time. (YYYY-MM-DD-hhmm) '
+            '\nPlease enter a starting time. '
+            '(YYYY-MM-DD-hhmm, or enter "m" to manually enter an activity) '
         )
 
-        while True:
-            self.entered_date += (
-                datetime.now(dateutil.tz.tzlocal()).strftime('%z')
-            )
-
-            try:
-                self.start_date = datetime.strptime(
-                    self.entered_date, '%Y-%m-%d-%H%M%z'
-                )
-                break
-            except ValueError:
-                self.entered_date = input(
-                    '\nInvalid answer. '
-                    '(Please enter a date in YYYY-MM-DD-hhmm format) '
+        if self.entered_date == 'm':
+            self.activities.append(ManualActivity(self))
+        else:
+            while True:
+                self.entered_date += (
+                    datetime.now(dateutil.tz.tzlocal()).strftime('%z')
                 )
 
-        entries = self.feed.entries
-        entries.reverse()
+                try:
+                    self.start_date = datetime.strptime(
+                        self.entered_date, '%Y-%m-%d-%H%M%z'
+                    )
+                    break
+                except ValueError:
+                    self.entered_date = input(
+                        '\nInvalid answer. '
+                        '(Please enter a date in YYYY-MM-DD-hhmm format) '
+                    )
 
-        self.stop = False
-        for entry in entries:
-            if self.stop:
-                break
+            self.stop = False
+            for item in self.sohr:
+                if self.stop:
+                    break
 
-            entry_date = (
-                entry.published[::-1].replace(':'[::-1], ''[::-1], 1)[::-1]
-            )
-            entry_date = datetime.strptime(
-                entry_date, '%Y-%m-%dT%H:%M:%S%z'
-            )
-            
-            if entry_date >= self.start_date:
-                self.posts.append(Post(self, entry, entry_date))
+                item_date = item['date'].strftime('%Y-%m-%dT%H:%M:%S') + '+0000'
+                item_date = datetime.strptime(item_date, '%Y-%m-%dT%H:%M:%S%z')
+
+                if item_date >= self.start_date:
+                    self.posts.append(Post(self, item, item_date))
 
         print(
             '\nSaved CSV as', self.csv_path,
         )
 
     def csvwrite(self, values):
-        with open(self.csv_path, 'a', newline='') as csvfile:
+        with open(self.csv_path, 'a') as csvfile:
             csvwriter = csv.writer(csvfile, dialect='excel')
             csvwriter.writerow(values)
