@@ -2,12 +2,13 @@ from .activity import Activity
 from bs4 import BeautifulSoup
 from datetime import datetime
 import dateutil.tz
+from .manual_activity import ManualActivity
 
 
 class Post():
-    def __init__(self, home, entry, date):
+    def __init__(self, home, item, date):
         self.home = home
-        self.entry = entry
+        self.item = item
 
         self.date = date
         self.now = datetime.now(dateutil.tz.tzlocal())
@@ -16,13 +17,9 @@ class Post():
         self.short_date = self.current_date.strftime('%Y-%m-%d')
         self.time = self.current_date.strftime('%Y-%m-%d-%H%M')
 
-        self.link = self.entry.link
+        self.link = self.item['link']
+        self.content = self.item['content']
 
-        self.content = self.entry.content[0]['value']
-        self.content = BeautifulSoup(self.content)
-        self.content = str(self.content)
-
-        print('\nPost content (' + self.time + '):\n' + self.content)
         self.clean_content = self.content.translate(str.maketrans('', '', ':'))
         self.words = self.clean_content.split()
 
@@ -54,21 +51,21 @@ class Post():
         self.contents = []
 
         self.strategic_terms = [
-                'clash',
-                'bomb ',
-                'ied',
-                'vbied',
-                'air',
-                'helicopter',
-                'seize',
-                'capture',
-                'taken over',
-                'take control',
-                'ambush',
-                'raid',
-                'suicide',
-                'fighter-jet',
-            ]
+            'clash',
+            'bomb ',
+            ' ied ',
+            'vbied',
+            'air',
+            'helicopter',
+            'seize',
+            'capture',
+            'taken over',
+            'take control',
+            'ambush',
+            'raid',
+            'suicide',
+            'fighter-jet',
+        ]
 
         for sentence in self.sentences:
             words = sentence.split()
@@ -84,19 +81,7 @@ class Post():
                 else:
                     self.contents.append(sentence)
 
-        print(
-            '\nAre there ' + str(len(self.contents)) +
-            ' activities in this post '
-            'with the following contents:'
-        )
-
-        for number in range(0, len(self.contents)):
-            print('\n' + str(number + 1) + ': ' + self.contents[number])
-
-        answer = input(
-            '\n? (If correct, press Enter. '
-            'Otherwise, enter the number of activities in this post, or enter "q" to finish entering posts) '
-        )
+        answer = self.layout()   
 
         while True:
             if answer == '':
@@ -108,6 +93,10 @@ class Post():
             if answer == 'q':
                 self.home.stop = True
                 break
+            if answer == 'm':
+                self.home.activities.append(ManualActivity(home))
+                answer = self.layout()
+                continue
             try:
                 answer = int(answer)
             except ValueError:
@@ -147,3 +136,22 @@ class Post():
                     if subject.find(element) != -1:
                         return True
         return False
+    
+    def layout(self):
+        print('\nPost content (' + self.time + '):\n' + self.content)
+
+        print(
+            '\nAre there ' + str(len(self.contents)) +
+            ' activities in this post '
+            'with the following contents:'
+        )
+
+        for number in range(0, len(self.contents)):
+            print('\n' + str(number + 1) + ': ' + self.contents[number])
+
+        return input(
+            '\n? (If correct, press Enter. '
+            'Otherwise, enter the number of activities in this post. '
+            'Enter "m" to enter an activity manually, or '
+            'enter "q" to finish entering posts) '
+        )
